.. _examples:

Examples
========

The following examples show the main feature of the ``NeuroTS`` package.

It is possible to run them and to explore their results online using
`MyBinder <https://mybinder.org/v2/gh/BlueBrain/NeuroTS/main?labpath=examples%2Fexplore_example_results.ipynb>`_.
